/* The content of this file is generated from:
# DerivedCoreProperties-15.1.0.txt
# Date: 2023-08-07, 15:21:24 GMT
*/

#include "indicconjunctbreakdef.h"

static const struct IndicConjunctBreakProperties incb_prop[] = {
    {0x0300, 0x034E, InCB_Extend},
    {0x0350, 0x036F, InCB_Extend},
    {0x0483, 0x0487, InCB_Extend},
    {0x0591, 0x05BD, InCB_Extend},
    {0x05BF, 0x05BF, InCB_Extend},
    {0x05C1, 0x05C2, InCB_Extend},
    {0x05C4, 0x05C5, InCB_Extend},
    {0x05C7, 0x05C7, InCB_Extend},
    {0x0610, 0x061A, InCB_Extend},
    {0x064B, 0x065F, InCB_Extend},
    {0x0670, 0x0670, InCB_Extend},
    {0x06D6, 0x06DC, InCB_Extend},
    {0x06DF, 0x06E4, InCB_Extend},
    {0x06E7, 0x06E8, InCB_Extend},
    {0x06EA, 0x06ED, InCB_Extend},
    {0x0711, 0x0711, InCB_Extend},
    {0x0730, 0x074A, InCB_Extend},
    {0x07EB, 0x07F3, InCB_Extend},
    {0x07FD, 0x07FD, InCB_Extend},
    {0x0816, 0x0819, InCB_Extend},
    {0x081B, 0x0823, InCB_Extend},
    {0x0825, 0x0827, InCB_Extend},
    {0x0829, 0x082D, InCB_Extend},
    {0x0859, 0x085B, InCB_Extend},
    {0x0898, 0x089F, InCB_Extend},
    {0x08CA, 0x08E1, InCB_Extend},
    {0x08E3, 0x08FF, InCB_Extend},
    {0x0915, 0x0939, InCB_Consonant},
    {0x093C, 0x093C, InCB_Extend},
    {0x094D, 0x094D, InCB_Linker},
    {0x0951, 0x0954, InCB_Extend},
    {0x0958, 0x095F, InCB_Consonant},
    {0x0978, 0x097F, InCB_Consonant},
    {0x0995, 0x09A8, InCB_Consonant},
    {0x09AA, 0x09B0, InCB_Consonant},
    {0x09B2, 0x09B2, InCB_Consonant},
    {0x09B6, 0x09B9, InCB_Consonant},
    {0x09BC, 0x09BC, InCB_Extend},
    {0x09CD, 0x09CD, InCB_Linker},
    {0x09DC, 0x09DD, InCB_Consonant},
    {0x09DF, 0x09DF, InCB_Consonant},
    {0x09F0, 0x09F1, InCB_Consonant},
    {0x09FE, 0x09FE, InCB_Extend},
    {0x0A3C, 0x0A3C, InCB_Extend},
    {0x0A95, 0x0AA8, InCB_Consonant},
    {0x0AAA, 0x0AB0, InCB_Consonant},
    {0x0AB2, 0x0AB3, InCB_Consonant},
    {0x0AB5, 0x0AB9, InCB_Consonant},
    {0x0ABC, 0x0ABC, InCB_Extend},
    {0x0ACD, 0x0ACD, InCB_Linker},
    {0x0AF9, 0x0AF9, InCB_Consonant},
    {0x0B15, 0x0B28, InCB_Consonant},
    {0x0B2A, 0x0B30, InCB_Consonant},
    {0x0B32, 0x0B33, InCB_Consonant},
    {0x0B35, 0x0B39, InCB_Consonant},
    {0x0B3C, 0x0B3C, InCB_Extend},
    {0x0B4D, 0x0B4D, InCB_Linker},
    {0x0B5C, 0x0B5D, InCB_Consonant},
    {0x0B5F, 0x0B5F, InCB_Consonant},
    {0x0B71, 0x0B71, InCB_Consonant},
    {0x0C15, 0x0C28, InCB_Consonant},
    {0x0C2A, 0x0C39, InCB_Consonant},
    {0x0C3C, 0x0C3C, InCB_Extend},
    {0x0C4D, 0x0C4D, InCB_Linker},
    {0x0C55, 0x0C56, InCB_Extend},
    {0x0C58, 0x0C5A, InCB_Consonant},
    {0x0CBC, 0x0CBC, InCB_Extend},
    {0x0D15, 0x0D3A, InCB_Consonant},
    {0x0D3B, 0x0D3C, InCB_Extend},
    {0x0D4D, 0x0D4D, InCB_Linker},
    {0x0E38, 0x0E3A, InCB_Extend},
    {0x0E48, 0x0E4B, InCB_Extend},
    {0x0EB8, 0x0EBA, InCB_Extend},
    {0x0EC8, 0x0ECB, InCB_Extend},
    {0x0F18, 0x0F19, InCB_Extend},
    {0x0F35, 0x0F35, InCB_Extend},
    {0x0F37, 0x0F37, InCB_Extend},
    {0x0F39, 0x0F39, InCB_Extend},
    {0x0F71, 0x0F72, InCB_Extend},
    {0x0F74, 0x0F74, InCB_Extend},
    {0x0F7A, 0x0F7D, InCB_Extend},
    {0x0F80, 0x0F80, InCB_Extend},
    {0x0F82, 0x0F84, InCB_Extend},
    {0x0F86, 0x0F87, InCB_Extend},
    {0x0FC6, 0x0FC6, InCB_Extend},
    {0x1037, 0x1037, InCB_Extend},
    {0x1039, 0x103A, InCB_Extend},
    {0x108D, 0x108D, InCB_Extend},
    {0x135D, 0x135F, InCB_Extend},
    {0x1714, 0x1714, InCB_Extend},
    {0x17D2, 0x17D2, InCB_Extend},
    {0x17DD, 0x17DD, InCB_Extend},
    {0x18A9, 0x18A9, InCB_Extend},
    {0x1939, 0x193B, InCB_Extend},
    {0x1A17, 0x1A18, InCB_Extend},
    {0x1A60, 0x1A60, InCB_Extend},
    {0x1A75, 0x1A7C, InCB_Extend},
    {0x1A7F, 0x1A7F, InCB_Extend},
    {0x1AB0, 0x1ABD, InCB_Extend},
    {0x1ABF, 0x1ACE, InCB_Extend},
    {0x1B34, 0x1B34, InCB_Extend},
    {0x1B6B, 0x1B73, InCB_Extend},
    {0x1BAB, 0x1BAB, InCB_Extend},
    {0x1BE6, 0x1BE6, InCB_Extend},
    {0x1C37, 0x1C37, InCB_Extend},
    {0x1CD0, 0x1CD2, InCB_Extend},
    {0x1CD4, 0x1CE0, InCB_Extend},
    {0x1CE2, 0x1CE8, InCB_Extend},
    {0x1CED, 0x1CED, InCB_Extend},
    {0x1CF4, 0x1CF4, InCB_Extend},
    {0x1CF8, 0x1CF9, InCB_Extend},
    {0x1DC0, 0x1DFF, InCB_Extend},
    {0x200D, 0x200D, InCB_Extend},
    {0x20D0, 0x20DC, InCB_Extend},
    {0x20E1, 0x20E1, InCB_Extend},
    {0x20E5, 0x20F0, InCB_Extend},
    {0x2CEF, 0x2CF1, InCB_Extend},
    {0x2D7F, 0x2D7F, InCB_Extend},
    {0x2DE0, 0x2DFF, InCB_Extend},
    {0x302A, 0x302D, InCB_Extend},
    {0x302E, 0x302F, InCB_Extend},
    {0x3099, 0x309A, InCB_Extend},
    {0xA66F, 0xA66F, InCB_Extend},
    {0xA674, 0xA67D, InCB_Extend},
    {0xA69E, 0xA69F, InCB_Extend},
    {0xA6F0, 0xA6F1, InCB_Extend},
    {0xA82C, 0xA82C, InCB_Extend},
    {0xA8E0, 0xA8F1, InCB_Extend},
    {0xA92B, 0xA92D, InCB_Extend},
    {0xA9B3, 0xA9B3, InCB_Extend},
    {0xAAB0, 0xAAB0, InCB_Extend},
    {0xAAB2, 0xAAB4, InCB_Extend},
    {0xAAB7, 0xAAB8, InCB_Extend},
    {0xAABE, 0xAABF, InCB_Extend},
    {0xAAC1, 0xAAC1, InCB_Extend},
    {0xAAF6, 0xAAF6, InCB_Extend},
    {0xABED, 0xABED, InCB_Extend},
    {0xFB1E, 0xFB1E, InCB_Extend},
    {0xFE20, 0xFE2F, InCB_Extend},
    {0x101FD, 0x101FD, InCB_Extend},
    {0x102E0, 0x102E0, InCB_Extend},
    {0x10376, 0x1037A, InCB_Extend},
    {0x10A0D, 0x10A0D, InCB_Extend},
    {0x10A0F, 0x10A0F, InCB_Extend},
    {0x10A38, 0x10A3A, InCB_Extend},
    {0x10A3F, 0x10A3F, InCB_Extend},
    {0x10AE5, 0x10AE6, InCB_Extend},
    {0x10D24, 0x10D27, InCB_Extend},
    {0x10EAB, 0x10EAC, InCB_Extend},
    {0x10EFD, 0x10EFF, InCB_Extend},
    {0x10F46, 0x10F50, InCB_Extend},
    {0x10F82, 0x10F85, InCB_Extend},
    {0x11070, 0x11070, InCB_Extend},
    {0x1107F, 0x1107F, InCB_Extend},
    {0x110BA, 0x110BA, InCB_Extend},
    {0x11100, 0x11102, InCB_Extend},
    {0x11133, 0x11134, InCB_Extend},
    {0x11173, 0x11173, InCB_Extend},
    {0x111CA, 0x111CA, InCB_Extend},
    {0x11236, 0x11236, InCB_Extend},
    {0x112E9, 0x112EA, InCB_Extend},
    {0x1133B, 0x1133C, InCB_Extend},
    {0x11366, 0x1136C, InCB_Extend},
    {0x11370, 0x11374, InCB_Extend},
    {0x11446, 0x11446, InCB_Extend},
    {0x1145E, 0x1145E, InCB_Extend},
    {0x114C3, 0x114C3, InCB_Extend},
    {0x115C0, 0x115C0, InCB_Extend},
    {0x116B7, 0x116B7, InCB_Extend},
    {0x1172B, 0x1172B, InCB_Extend},
    {0x1183A, 0x1183A, InCB_Extend},
    {0x1193E, 0x1193E, InCB_Extend},
    {0x11943, 0x11943, InCB_Extend},
    {0x11A34, 0x11A34, InCB_Extend},
    {0x11A47, 0x11A47, InCB_Extend},
    {0x11A99, 0x11A99, InCB_Extend},
    {0x11D42, 0x11D42, InCB_Extend},
    {0x11D44, 0x11D45, InCB_Extend},
    {0x11D97, 0x11D97, InCB_Extend},
    {0x11F42, 0x11F42, InCB_Extend},
    {0x16AF0, 0x16AF4, InCB_Extend},
    {0x16B30, 0x16B36, InCB_Extend},
    {0x1BC9E, 0x1BC9E, InCB_Extend},
    {0x1D165, 0x1D165, InCB_Extend},
    {0x1D167, 0x1D169, InCB_Extend},
    {0x1D16E, 0x1D172, InCB_Extend},
    {0x1D17B, 0x1D182, InCB_Extend},
    {0x1D185, 0x1D18B, InCB_Extend},
    {0x1D1AA, 0x1D1AD, InCB_Extend},
    {0x1D242, 0x1D244, InCB_Extend},
    {0x1E000, 0x1E006, InCB_Extend},
    {0x1E008, 0x1E018, InCB_Extend},
    {0x1E01B, 0x1E021, InCB_Extend},
    {0x1E023, 0x1E024, InCB_Extend},
    {0x1E026, 0x1E02A, InCB_Extend},
    {0x1E08F, 0x1E08F, InCB_Extend},
    {0x1E130, 0x1E136, InCB_Extend},
    {0x1E2AE, 0x1E2AE, InCB_Extend},
    {0x1E2EC, 0x1E2EF, InCB_Extend},
    {0x1E4EC, 0x1E4EF, InCB_Extend},
    {0x1E8D0, 0x1E8D6, InCB_Extend},
    {0x1E944, 0x1E94A, InCB_Extend},
};
