static const unsigned int testSkipsWord[] = {
    0
};

static const unsigned int testSkipsGrapheme[] = {
    0
};

static const unsigned int testSkipsLine[] = {
     7681,  /* Unknown (XX) is treated as AL in this implementation */
     0
};
